==> bacula-docs-5.0.2.tar.bz2: bacula-docs-5.0.2/home-page/en/pages/professional.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
    <td class="contentTopic">
       Professional Support for Bacula
    </td>
</tr>

<tr>
    <td class="content">
    In October 2008, <a
    href="http://www.baculasystems.com">Bacula Systems SA</a>,
    the professional support organization specifically for Bacula
    was announced.  You can access the official press release 
    <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Bacula-Systems-launches">
    here.</a><br><br>

    I (Kern) am the chairman and CTO of Bacula Systems, so I can personally
    vouch for the quality of support it provides. For those who are interested
    in why there is a need for Bacula Systems along side the Bacula Open Source
    community, please read my
    <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Kern-Sibbald-s-letter-to-the-Community">
    Letter to the community</a>.<br><br>

    Bacula Systems' goal is to offer subscriptions, training, and consulting
    services for all levels of Bacula users by working with and through
    qualified Bacula Systems Partners who are knowledgeable and close 
    to the customer. If you are interested in support, please see the
    Bacula Systems web site as follows:
</tr>
<tr>
   <td class="content">
   <table align="left">
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
         <td style="font-weight: bold">
                 Bacula Systems SA
         </td>
         <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
         <td>
            <a href="mailto:infoNOSPAM@baculasystems.com">Bacula Systems SA</a><br>
            Rue Galil&eacute;e 15<br>
            CH-1400 Yverdon-les-Bains, Switzerland<br>
            +41 24 420 7890<br>
            <br>
            <a href="http://www.baculasystems.com">http://www.baculasystems.com</a>
         </td>
      </tr>
   </table>
   </td>
</tr>


<tr>
    <td class="content">
       The following companies are Bacula Systems Partners, and as such,
       we know them well and Bacula Systems stands behind them and supports
       them.<br>
       <br>
       All email-addresses are extended with a 'NOSPAM'-tag, please remove it before sending an email.<br>
    </td>
</tr>
<tr>
   <td class="content">
   <table align="center">

      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      dass IT GmbH
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNSPAM@dass-it.de">dass IT GmbH</a> -- a Bacula Systems Partner<br>
                 H&auml;ndelstra&#223;e 25-29<br>
                 50674 K&ouml;ln<br>
                 Germany<br>
                 Tel: +49 221 35 65 666 - 0<br>
                 Fax: +49 221 35 65 666 - 10<br>
                 <br>
                 dass IT provides professional services and
                 support using mainly open source tools.  Our
                 focus lies on system management for a large
                 number of systems (servers and desktops).  We
                 provide services and solutions mainly for Linux
                 based IT infrastructures.  
                 <br> 
                 <a href="http://www.dass-it.de/">http://www.dass-it.de/</a>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      IT-Service Lehmann
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@its-lehmann.de">Arno Lehmann</a> -- a Bacula Systems Partner<br>
                  Sandstr. 6<br>
                  49080 Osnabr&uuml;ck</br>
                  Germany<br>
                  +49 (0) 541 5803396<br>
                  +49 (0) 160 92008971 (mobile)<br>
                  <br>
                  Storage, Communication, Backup and Monitoring using 
                  Open-Source solutions.  Services from
                  network design to system administration and
                  user education, with a focus on Small
                  Businesses looking for cost-effective solutions.
                  <br>
                  <a href="http://www.its-lehmann.de">http://www.its-lehmann.de</a>
               </td>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                  MigraTech
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                  MigraTech -- A Bacula Systems Partner<br>
                  Philippe Chauvat<br>
                  7 rue Alfred Kastler<br>
                  Immeuble Emergence<br>
                  14000 Caen<br>
                  France<br>

                  +33 (0) 231 75 14 91<br>
                  <br>
                  Migratech is a company that provides services for Free Software.
                  We propose a broad range of services that go from consulting
                  to installation of complete systems: sercurity (access, contents,
                  antivirus, antispam), data sharing, messaging, backup, and
                  large WiFi networks. For Backup, MigraTech has become a specialist
                  in Bacula.  Please visit our site (in French) for additional
                  information.<br>
                  <br>
                  <a href="http://www.migratech.fr">http://www.migratech.fr</a><br>
              </td>
      </tr>
   </table>
   </td>

</tr>


<tr>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>

<tr>
    <td class="contentTopic">
       Independent Contractors
    </td>
</tr>

    <td class="content">
       The following people are independent contractors. Each has worked
       with Bacula, and we are pleased to list their names here as a service, but
       without any guarantees.<br>
       <br>
       If you wish to be listed here, please read the 'Listing license' for further details: 
            <a href="?page=listlic">Listing license</a><br>
       <br>
       All email-addresses are extended with a 'NOSPAM'-tag, please 
       remove it before sending an email.<br>
    </td>
</tr>
<tr>
   <td class="content">
   <table align="center">
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Alixen
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@alixen.fr">Gilles Polart-Donat</a><br>
                 20 rue Jean Rostand<br>
                 91400 Orsay, France<br>
                 +33 01 60 19 72 31<br>
                 <br>
                 <a href="http://www.alixen.fr">http://www.alixen.fr</a>
              </td>
      </tr>

      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Arden Group Inc
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:rberryNOSPAM@ardengrp.com">Roger Berry</a><br>
                 5026 NE Clackamas<br>
                 Portland, OR 97213 USA<br>
                 +1(971)223-3987<br>
                 <br>
                 <a href="http://www.ardengrp.com">http://www.ardengrp.com</a><br>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      BSDCan
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:danNOSPAM@langille.org">Dan Langille</a><br>
                 Suite 474<br>
                 900 Greenbank Road<br>
                 Ottawa, ON K2J 4P6<br>
                 +1 215 882 0565<br>
                 <br>
                 Dan has been a Bacula developer since early 2004 when he wrote
                 the PostgreSQL plugin.  He is also the Bacula maintainer for
                 FreeBSD and has been writing and speaking about Bacula for 
                 several years.  As a consultant, his Bacula speciality is
                 design, installation, and configuration of new systems.  He is
                 available for consulting on any project.
                 
                 <br>
                 Reference available upon request.
                 
                 <br>
                 <a href="http://www.langille.org/">http://www.langille.org/</a>
              </td>
      </tr>



      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     Heitor Faria
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:heitorfariaNOSPAM@hotmail.com">Heitor Faria</a><br>
                 Consultoria, treinamento e suporte<br> 
                 <br>
                 Telephone +55 71 9983-3833<br>
                 <br>
                 <br>
                 Consultancy, training and support.
                 <br>
                 <a href="http://bacula.wordpress.com">http://bacula.wordpress.com</a>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                 KDB Konsult AB
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:matsNOSPAM@kdb.se">Mats Vilhelmsson</a><br>
                 Tel: +46 708 901042<br>
                 <br>
                 Backup hosting - Internet backups, Bacula training, installations and support.<br>
                 <br>
                 <a href="http://www.kdb.se">http://www.kdb.se</a><br>
              </td>
      </tr>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      L. Strappazon
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:l.strappazonNOSPAM@gmail.com">Ludovic Strappazon</a><br>
                 Strasbourg, France<br>
                 +33 6 42 58 97 42<br>
                 <br>
                 I offer engineering services and training around storage and Backup. 
                 Planning and scaling of your hardware installation, Bacula implementation.
              </td>
      </tr>

      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                  MATRIX-Computer
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                  MATRIX-Computer GmbH<br>
                  Dachauer Str. 44<br>
                  80335 M&uuml;nchen<br>
                  Germany<br>

                  +49-89-922 996 80<br>
                  <br>
                  We are a team of software developers with experience in C++, Windows, PHP, 
                  Linux and more. We have done lots of the Think Tools software.<br>
                  <br>
                  <a href="http://www.matrix-computer.com">http://www.matrix-computer.com</a><br>
              </td>
      </tr>



      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                     NETWAYS GmbH
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@netways.de">NETWAYS GmbH</a><br>
                 Deutschherrnstrasse 47a<br>
                 90429 N&uuml;rnberg<br>
                 Germany<br>
                 <br>
                 Telephone +49 911 92885-0<br>
                 Fax +49 911 92885-77<br>
                 <br>
                 <br>
                 We support our customers managing complex and
                 heterogeneous networks.  Our services and
                 solutions, based on Open Source software, help
                 you run your servers and applications
                 failure-free.  Special focus on Nagios, Bacula,
                 Request Tracker, and cluster solutions.  <br> 
                 <br>
                 <a href="http://www.netways.de">http://www.netways.de</a><br>
              </td>
      </tr>


      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                    m&uuml;ller it gmbh
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:serviceNOSPAM@muellerit.ch">m&uuml;ller it gmbh</a><br>
                 Hagenholzstrasse 76<br>
                 8050 Z&uuml;rich
                 Schweiz
                 <br>
                 Telephone +41 (0)43 536 49 75<br>
                 Skype mueller.it.gmbh
                 <br>
                 <br>
                 IT L&ouml;sungen & Services f&uuml;r KMU's.
                 <br>
                 <a href="http://www.muellerit.ch">http://www.muellerit.ch</a><br>
              </td>
      </tr>



      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
              <td style="font-weight: bold">
                      Sine Nomine Associates
              </td>
              <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
              <td>
                 <a href="mailto:infoNOSPAM@sinenomine.net">Services Sales Dept.</a><br>
                 US:<br>
                 &nbsp;&nbsp;43596 Blacksmith Square <br>
                 &nbsp;&nbsp;Ashburn, VA 20147 USA <br>
                 &nbsp;&nbsp;+1 703 723 6673<br>
                 <br>
                 EMEA:<br>
                 &nbsp;&nbsp;Na Dvorcich 17/Na Vrasni 18<br>
                 &nbsp;&nbsp;CZ - Praha 4, 14000 <br>
                 &nbsp;&nbsp;Czech Republic<br>
                 <br>
                 Design and implementation of system management tools and infrastructure,<br>
                 from small systems to enterprise-wide implementations on global scale.<br>
                 Special focus on Bacula for enterprise-class systems and mainframe.<br>
                 <br>
                 <a href="http://www.sinenomine.net">http://www.sinenomine.net</a><br>
              </td>
      </tr>


   </table>
   </td>
</tr>
</table>
<? require_once("inc/footer.php"); ?>

==> bacula-docs-5.2.2.tar.bz2: bacula-docs-5.2.2/home-page/en/pages/professional.php <==
<? require_once("inc/header.php"); ?>
<table>
<tr>
    <td class="contentTopic">
       Professional Support for Bacula
    </td>
</tr>

<tr>
    <td class="content">
    In October 2008, <a
    href="http://www.baculasystems.com">Bacula Systems SA</a>,
    the professional support organization specifically for Bacula
    was announced.  You can access the official press release 
    <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Bacula-Systems-launches">
    here.</a><br><br>

    I (Kern) am the chairman and CTO of Bacula Systems, so I can personally
    vouch for the quality of support it provides. For those who are interested
    in why there is a need for Bacula Systems along side the Bacula Open Source
    community, please read my
    <a href="http://www.baculasystems.com/eng/About-us/Recent-news/Kern-Sibbald-s-letter-to-the-Community">
    Letter to the community</a>.<br><br>

    Bacula Systems offers subscriptions, training, consulting, and
    funded development services for all levels of Bacula users by working with
    and through qualified Bacula Systems Partners who are knowledgeable and
    close to the customer.  If you are interested in support, please see the
    Bacula Systems web site as follows:
</tr>
<tr>
   <td class="content">
   <table align="left">
      <tr> <td colspan="3"><hr></td>
      <tr> <td colspan="3"><img src="/images/spacer.gif" width="50px" height="25px"></td> </tr>
      <tr>
         <td style="font-weight: bold">
                 Bacula Systems SA
         </td>
         <td><img src="/images/spacer.gif" width="50px" height="1px"></td>
         <td>
            <a href="mailto:infoNOSPAM@baculasystems.com">Bacula Systems SA</a><br>
            Rue Galil&eacute;e 5<br>
            CH-1400 Yverdon-les-Bains, Switzerland<br>
            +41 21 641 6080<br>
            <br>
            <a href="http://www.baculasystems.com">http://www.baculasystems.com</a>
         </td>
      </tr>
   </table>
   </td>
</tr>


</table>
<? require_once("inc/footer.php"); ?>
